```json
{
  "title": "SCP-9935 - SCP Foundation",
  "author": "",
  "site": "",
  "published": ""
}
```

![baseballbanner.jpg](https://scp-wiki.wdfiles.com/local--files/scp-9935/baseballbanner.jpg)

Bruce Park, Indianapolis, 1889.

| **Assigned Department** | **Department Head** | **Research Head** | **Assigned Task Force** |
| --- | --- | --- | --- |
| Structures, Constructs, and Patterns | Dr. Constance Evermore | Dr. Claire Higgins | Delta-23 "Batboys" |

**Special Containment Procedures:** Foundation containment of SCP-9935 has, since initial containment in 1920, required a large-scale misinformation campaign targeting available public records regarding SCP-9935, its participants, and Bruce Park. The game is ongoing, and is being played currently.

**Description:** SCP-9935 is an anomalous baseball game between the Indianapolis Hoosiers and the Washington Nationals [^1] that began on October 5th, 1889 and is still ongoing. Neither team has scored a run since the original game became tied in the 35th inning. Both teams folded before the start of the next season [^2].

Jack Glasscock [^3], the Hoosiers shortstop and team captain, provided the following account of the early innings.

> *"Me and John went out to speak with Bill about stoppin' things, for we were all bone-tired, but he just shook his head and said the game had to be played out, no matter the hour."*

## Rosters

| Indianapolis | Pos. | Washington |
| --- | --- | --- |
| Con Daily, 24 | C | Tom Daly, 23 |
| Jack Glasscock, 31 | SS | Arthur Irwin, 31 |
| Jerry Denny, 30 | 3B | John Irwin, 27 |

[^1]: No relation to the Washington Nationals team of the modern day.

[^2]: The fact that both teams folded was not unusual, as both had been mired in multiple seasons of poor performance.

[^3]: Jack Glasscock, Hoosiers shortstop and team captain.